function BuildIndex(UTS_D,Index_D,feature_ind,window_size,Ref_D, ref_ind, Num_MTS)
% Build the index for 'feature_ind' (all UTS are stored in the UTS_D) 
% using refrence point 'ref_ind'(one ref point) in Ref_D
% so each call create one sorted list (our index) for one feature based on one ref point

% Index will be output to Index_D, and stored into multiple sections (since the whole index would be very long)
% each section will contain 'Size_IndexUnit' items (we set it to 1e+5 when total number of subsequence is around 2~3e+7)
% file '\Index_D\feature_ind\ref_ind\n' contains the 'n'th section of index for 'feature_ind' using 'ref_ind'

Size_IndexUnit = 10000;
Avg_Length = 5000;
MAXNUM_Window = Num_MTS * Avg_Length; %upbound size for our indexing list
dist_mts_offset = zeros(MAXNUM_Window,3,'single'); %record the 'dist' from ref point to the subsequence in "mts" at "offset"

Ref_filename = [Ref_D '/RefPoints_F' num2str(feature_ind) '.txt'];
RefPoints = load(Ref_filename);
r = RefPoints(:,ref_ind); %the refrence point we're going to use


%% First calculate distance from ref to all sliding window
Num_UTS = 0;
Num_slidingwindow = 0;
UTS_D = [UTS_D '/' num2str(feature_ind)];
flist=dir(UTS_D);
fnum = length(flist);
i = 1;
while i <= fnum    
    if ~flist(i).isdir && ~strcmp(flist(i).name,'Thumbs.db')
        Num_UTS = Num_UTS + 1;
        UTS = load(sprintf('%s/%s',UTS_D,flist(i).name));
        uts_ind = str2num(flist(i).name(1:length(flist(i).name)-4));
        Max_Offset = length(UTS) - window_size + 1;
        for j = 1:Max_Offset % for all the offset(sliding window)
            Num_slidingwindow = Num_slidingwindow + 1;
            t = UTS(j:j+window_size-1);
%             t = (t - mean(t))./std(t);
            dist_mts_offset(Num_slidingwindow,:) = [Lp_dist(t,r,2),uts_ind,j];
        end
    end
    i = i + 1;
end

%% Sort
[tmp, pos] = sort(dist_mts_offset(1:Num_slidingwindow,1)); %sort by dist
dist_mts_offset = dist_mts_offset(pos,:); %adjust the pos

%% Output the index (Put every 'Size_IndexUnit' index items into a file)
filenum = floor(Num_slidingwindow/Size_IndexUnit);
min_max = zeros(filenum+1,2); %record min and max value for each output unit
if(~exist([Index_D '/' num2str(feature_ind) '/' num2str(ref_ind)],'dir'))
    mkdir(Index_D, [num2str(feature_ind) '/' num2str(ref_ind)]);
end
foldername = [Index_D '/' num2str(feature_ind) '/' num2str(ref_ind)];
for i = 1:filenum
    start_ind = (i-1)* Size_IndexUnit + 1;
    end_ind = i * Size_IndexUnit;
    min_max(i,:) = [dist_mts_offset(start_ind,1),dist_mts_offset(end_ind,1)];
    filename = [foldername '/' num2str(i)];
    tmp = dist_mts_offset(start_ind:end_ind,:);
    save (filename, 'tmp');
end
start_ind = filenum * Size_IndexUnit + 1;
end_ind = Num_slidingwindow;
min_max(filenum + 1,:) = [dist_mts_offset(start_ind,1),dist_mts_offset(end_ind,1)];
filename = [foldername '/' num2str(filenum+1)];
tmp = dist_mts_offset(start_ind:end_ind,:);
save (filename, 'tmp');
%output min_max
filename = [foldername '/min_max.txt'];
save (filename, 'min_max', '-ASCII');



