function [fnum] = MTS2UTS(MTS_D,UTS_D,feature_dim)

% Read MTS from MTS_D, extract features in feature_dim (array), and output UTS to UTS_D

% each MTS in MTS_D is a csv file
% the first row is the header (variable names)
% from second row is the data matrix where columns are the variables and times is down the rows.

% UTS from same feature will be stored in the same folder, with the name of the number of MTS where it's from
% i.e. the univariate sequence of ith varibale from jth MTS will be stored as : UTS_D\i\j.txt 


%make UTS directories for each variable
for i = 1:length(feature_dim)
    if(~exist([UTS_D '/' num2str(feature_dim(i))]))
        mkdir(UTS_D,num2str(feature_dim(i)));
    end
end

flist=dir([MTS_D '/' '*.csv']);
fnum = length(flist);
fprintf('Number of files to process %d\n',fnum);
i = 1;
Num_MTS = 0;
Num_feature = length(feature_dim);
t = cputime;
while i <= fnum    
    if ~flist(i).isdir && ~strcmp(flist(i).name,'Thumbs.db')&& ~strcmp(flist(i).name,'FlightListCLE.csv')
        Num_MTS = Num_MTS + 1; 
        fprintf('Processing file %s\n',flist(i).name);
        MTS = importdata(sprintf('%s/%s',MTS_D,flist(i).name)); %read in one MTS
        MTSname = num2str(Num_MTS);
        for j = 1:Num_feature
            UTS = MTS.data(:,feature_dim(j)); %extract the UTS
            %UTS = MTS(:,feature_dim(j)); %read in csv files which don't have header line
            UTSname = num2str(feature_dim(j));
            filename = [UTS_D '/' UTSname '/' MTSname '.txt'];
            save (filename, 'UTS', '-ASCII');
        end
    end
    i = i + 1;
    if ~mod(Num_MTS,100)
        fprintf('Processed file %d\n',Num_MTS);
    end
end


