function mts_offset = RangeQuery(foldername, th_l, th_h)
%search candidates for [th_l,th_h] on index files in the 'foldername'

Size_IndexUnit = 10000;
min_max_filename = [foldername '/min_max.txt'];
min_max = load(min_max_filename);
filenum = size(min_max,1);

%% Binary search to find one index file whose range intersects with [th_l, th_h]
intersect_ind = Binary_Search(th_l, th_h, filenum, min_max); 
if ~intersect_ind
    disp('Error! range cannot be found...');
    return;
end

%% then find the 1st intersection index file
tmp = intersect_ind -1;
while tmp >= 1
    if th_l <= min_max(tmp,2) && th_h >= min_max(tmp,1)
        tmp = tmp - 1;
    else
        break
    end
end
low_intersect_ind = tmp + 1;


%% then find the last intersection index file
tmp = intersect_ind + 1;
while tmp <= filenum
    if th_l <= min_max(tmp,2) && th_h >= min_max(tmp,1)
        tmp = tmp + 1;
    else
        break
    end
end
high_intersect_ind = tmp - 1;

max_size = (high_intersect_ind - low_intersect_ind + 1)*Size_IndexUnit;
mts_offset = zeros(max_size,2);


if low_intersect_ind ~= high_intersect_ind
    for i = low_intersect_ind : high_intersect_ind
        %read in index
        filename = [foldername '/' num2str(i)];
        indexfile = load(filename);
        index = indexfile.tmp;
        if i == low_intersect_ind %extract candidates from the 1st index file
            start_ind = find(index(:,1)>=th_l, 1);
            current_size = Size_IndexUnit - start_ind + 1;
            mts_offset(1:current_size,:) = index(start_ind:Size_IndexUnit,2:3);
        end
        if i == high_intersect_ind %extract candidates from the last index file,
            end_ind = find(index(:,1)>=th_h, 1)-1;
            mts_offset(current_size+1:current_size + end_ind,:) = index(1:end_ind,2:3);
            current_size = current_size + end_ind;
        end
        if i ~= low_intersect_ind && i~=high_intersect_ind %for other index file, add all items to mts_offset
            mts_offset(current_size+1:current_size+Size_IndexUnit,:) = index(:,2:3);
            current_size = current_size + Size_IndexUnit;
        end
    end
else
    %read in index
    filename = [foldername '/' num2str(low_intersect_ind)];
    indexfile = load(filename);
    index = indexfile.tmp;
    start_ind = find(index(:,1)>=th_l, 1);
    end_ind = find(index(:,1)>=th_h, 1)-1;
    current_size = end_ind - start_ind + 1;
    mts_offset(1:current_size,:) = index(start_ind:end_ind,2:3);
end
     

mts_offset(current_size+1:max_size,:) = [];


    
